[![MIT license](https://img.shields.io/badge/License-MIT-blue.svg)](https://lbesson.mit-license.org/)
[![PyPI version fury.io](https://badge.fury.io/py/ariadne-utils.svg)](https://pypi.org/project/ariadne-utils/)

# ariadne-utils

Utilities for using ariadne in Django, FastAPI, or other projects

## Installation

```shell script
$ pip install ariadne-utils --upgrade
```
[Official PyPi Repository](https://pypi.org/project/ariadne-utils/)